BluetoothPreference class

Constructors

BluetoothPreference({SSP enableSsp = SSP.NOCHANGE, PowerSaveMode powerMode = PowerSaveMode.NOCHANGE, AuthMode authMode = AuthMode.AUTH_NO_ENC_NO})

Properties

authMode ↔ AuthMode
getter/setter pair
enableSsp ↔ SSP
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
powerMode ↔ PowerSaveMode
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → BluetoothPreference