LabelInfo class

Constructors

LabelInfo({int labelNameIndex = -1, bool isAutoCut = true, bool isEndCut = true, bool isHalfCut = false, bool isSpecialTape = false, bool isCutMark = false, LabelColor labelColor = LabelColor.UNSUPPORT, LabelColor labelFontColor = LabelColor.UNSUPPORT, int labelType = -1})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAutoCut ↔ bool
getter/setter pair
isCutMark ↔ bool
getter/setter pair
isEndCut ↔ bool
getter/setter pair
isHalfCut ↔ bool
getter/setter pair
isSpecialTape ↔ bool
getter/setter pair
labelColor ↔ LabelColor
getter/setter pair
labelFontColor ↔ LabelColor
getter/setter pair
labelNameIndex ↔ int
getter/setter pair
labelType ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → LabelInfo