PT class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getId() → int
getName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromIndex(int index) → PT
fromMap(Map map) → PT
getItemId(dynamic index) → int
getValues() → List<PT>
ordinalFromID(int id) → int
valueFromID(int id) → PT

Constants

FLE_W21H45 → const PT
HS_W6 → const PT
HS_W9 → const PT
HS_W12 → const PT
HS_W18 → const PT
HS_W24 → const PT
R2_5 → const PT
R3_0 → const PT
R3_5 → const PT
R4_0 → const PT
R5_0 → const PT
R6_0 → const PT
R6_5 → const PT
UNSUPPORT → const PT
W3_5 → const PT
W6 → const PT
W9 → const PT
W12 → const PT
W18 → const PT
W24 → const PT
W36 → const PT