PT3 class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getId() → int
getName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromIndex(int index) → PT3
fromMap(Map map) → PT3
getItemId(dynamic index) → int
getValues() → List<PT3>
ordinalFromID(int id) → int
valueFromID(int id) → PT3

Constants

UNSUPPORT → const PT3
W3_5 → const PT3
W6 → const PT3
W9 → const PT3
W12 → const PT3