QL1100 class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getId() → int
getName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromIndex(int index) → QL1100
fromMap(Map map) → QL1100
getItemId(dynamic index) → int
getValues() → List<QL1100>
ordinalFromID(int id) → int
valueFromID(int id) → QL1100

Constants

UNSUPPORT → const QL1100
W12 → const QL1100
W17H54 → const QL1100
W17H87 → const QL1100
W23H23 → const QL1100
W29 → const QL1100
W29H42 → const QL1100
W29H90 → const QL1100
W38 → const QL1100
W38H90 → const QL1100
W39H48 → const QL1100
W50 → const QL1100
W52H29 → const QL1100
W54 → const QL1100
W60H86 → const QL1100
W62 → const QL1100
W62H29 → const QL1100
W62H100 → const QL1100
W102 → const QL1100
W102H51 → const QL1100
W102H152 → const QL1100
W103 → const QL1100
W103H164 → const QL1100