QL700 class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getId() → int
getName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromIndex(int index) → QL700
fromMap(Map map) → QL700
getItemId(dynamic index) → int
getValues() → List<QL700>
ordinalFromID(int id) → int
valueFromID(int id) → QL700

Constants

UNSUPPORT → const QL700
W12 → const QL700
W17H54 → const QL700
W17H87 → const QL700
W23H23 → const QL700
W29 → const QL700
W29H42 → const QL700
W29H90 → const QL700
W38 → const QL700
W38H90 → const QL700
W39H48 → const QL700
W50 → const QL700
W52H29 → const QL700
W54 → const QL700
W54H29 → const QL700
W60H86 → const QL700
W62 → const QL700
W62H29 → const QL700
W62H100 → const QL700
W62RB → const QL700