BatteryInfo class

Constructors

BatteryInfo({int chargeLevel = -1, int healthLevel = -1, HealthStatus healthStatus = HealthStatus.NotInstalled})

Properties

batteryChargeLevel → int
final
batteryHealthLevel → int
final
batteryHealthStatus → HealthStatus
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → BatteryInfo