BluetoothPrinter class

Implemented types
Implementers

Constructors

BluetoothPrinter({String modelName = "", String macAddress = ""})

Properties

hashCode → int
The hash code for this object.
no setteroverride
macAddress → String
final
modelName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromMap(Map map) → BluetoothPrinter