CustomPaperInfo class

Properties

bottomMargin → double
final
hashCode → int
The hash code for this object.
no setterinherited
labelPitch → double
final
leftMargin → double
final
markHeight → double
final
markPosition → double
final
paperKind → PaperKind
final
printerModel → Model
final
rightMargin → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tapeLength → double
final
tapeWidth → double
final
topMargin → double
final
unit → Unit
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map? map) → CustomPaperInfo?
newCustomDiaCutPaper(Model printerModel, Unit unit, double tapeWidth, double tapeLength, double rightMargin, double leftMargin, double topMargin, double bottomMargin, double labelPitch) → CustomPaperInfo
newCustomMarkRollPaper(Model printerModel, Unit unit, double tapeWidth, double tapeLength, double rightMargin, double leftMargin, double topMargin, double bottomMargin, double markPosition, double markHeight) → CustomPaperInfo
newCustomRollPaper(Model printerModel, Unit unit, double tapeWidth, double rightMargin, double leftMargin, double topMargin) → CustomPaperInfo