ErrorCode class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getId() → int
getName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → ErrorCode
getItemId(dynamic index) → int
getValues() → List<ErrorCode>
ordinalFromID(int id) → int
valueFromID(int id) → ErrorCode
valueFromName(String name) → ErrorCode

Constants

ERROR_BATTERY_EMPTY → const ErrorCode
ERROR_BATTERY_TROUBLE → const ErrorCode
ERROR_BROTHER_PRINTER_NOT_FOUND → const ErrorCode
ERROR_BUFFER_FULL → const ErrorCode
ERROR_BUSY → const ErrorCode
ERROR_CANCEL → const ErrorCode
ERROR_CHANGE_CASSETTE → const ErrorCode
ERROR_CLOSE_SOCKET_FAILED → const ErrorCode
ERROR_COMMUNICATION_ERROR → const ErrorCode
ERROR_CONNECT_SOCKET_FAILED → const ErrorCode
ERROR_COVER_OPEN → const ErrorCode
ERROR_CREATE_SOCKET_FAILED → const ErrorCode
ERROR_EVALUATION_TIMEUP → const ErrorCode
ERROR_FEED_OR_CASSETTE_EMPTY → const ErrorCode
ERROR_FILE_NOT_FOUND → const ErrorCode
ERROR_FILE_NOT_SUPPORTED → const ErrorCode
ERROR_GET_INPUT_STREAM_FAILED → const ErrorCode
ERROR_GET_OUTPUT_STREAM_FAILED → const ErrorCode
ERROR_HIGH_VOLTAGE_ADAPTER → const ErrorCode
ERROR_INTERNAL_ERROR → const ErrorCode
ERROR_INVALID_PARAMETER → const ErrorCode
ERROR_MINIMUM_LENGTH_LIMIT → const ErrorCode
ERROR_NO_ADDRESS → const ErrorCode
ERROR_NO_CASSETTE → const ErrorCode
ERROR_NO_SD_CARD → const ErrorCode
ERROR_NONE → const ErrorCode
ERROR_NOT_MATCH_ADDRESS → const ErrorCode
ERROR_NOT_SAME_MODEL → const ErrorCode
ERROR_OS_VERSION_NOT_SUPPORTED → const ErrorCode
ERROR_OUT_OF_MEMORY → const ErrorCode
ERROR_OVERHEAT → const ErrorCode
ERROR_PAPER_EMPTY → const ErrorCode
ERROR_PAPER_JAM → const ErrorCode
ERROR_PORT_NOT_SUPPORTED → const ErrorCode
ERROR_POWER_CABLE_UNPLUGGING → const ErrorCode
ERROR_PRINTER_SETTING_NOT_SUPPORTED → const ErrorCode
ERROR_RESOLUTION_MODE → const ErrorCode
ERROR_SET_OVER_MARGIN → const ErrorCode
ERROR_STORAGE_PERMISSION_NOT_GRANTED → const ErrorCode
ERROR_SYSTEM_ERROR → const ErrorCode
ERROR_TEMPLATE_FILE_NOT_MATCH_MODEL → const ErrorCode
ERROR_TEMPLATE_NOT_CONTROL_MODEL → const ErrorCode
ERROR_TEMPLATE_NOT_EXIST → const ErrorCode
ERROR_TEMPLATE_NOT_PRINT_MODEL → const ErrorCode
ERROR_TEMPLATE_NOT_TRANS_MODEL → const ErrorCode
ERROR_TUBE_CUTTER → const ErrorCode
ERROR_TUBE_EMPTY → const ErrorCode
ERROR_TUBE_RIBBON_EMPTY → const ErrorCode
ERROR_UNSUPPORTED_MEDIA → const ErrorCode
ERROR_UNSUPPORTED_MONO_COLOR → const ErrorCode
ERROR_UNSUPPORTED_TWO_COLOR → const ErrorCode
ERROR_UPDATE_FRIM_NOT_SUPPORTED → const ErrorCode
ERROR_WORKPATH_NOT_SET → const ErrorCode
ERROR_WRONG_CASSETTE_DIRECT → const ErrorCode
ERROR_WRONG_CUSTOM_INFO → const ErrorCode
ERROR_WRONG_LABEL → const ErrorCode
ERROR_WRONG_TEMPLATE_KEY → const ErrorCode