Margin class

Constructors

Margin({int top = 0, int left = 0})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
left → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → Margin