Msg class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getId() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → Msg
getItemId(dynamic index) → int
ordinalFromID(int id) → int
valueFromID(int id) → Msg

Constants

MESSAGE_CANCEL → const Msg
MESSAGE_END_COMMUNICATION → const Msg
MESSAGE_END_CONNECTED → const Msg
MESSAGE_END_COOLING → const Msg
MESSAGE_END_CREATE_DATA → const Msg
MESSAGE_END_GET_BLUETOOTH_SETTING → const Msg
MESSAGE_END_GET_INPUT_STREAM → const Msg
MESSAGE_END_GET_OUTPUT_STREAM → const Msg
MESSAGE_END_GET_TEMPLATE_LIST → const Msg
MESSAGE_END_READ_PRINTER_STATUS → const Msg
MESSAGE_END_REMOVE_TEMPLATE_LIST → const Msg
MESSAGE_END_SEND_DATA → const Msg
MESSAGE_END_SEND_STATUS_REQUEST → const Msg
MESSAGE_END_SEND_TEMPLATE → const Msg
MESSAGE_END_SOCKET_CLOSE → const Msg
MESSAGE_END_TRANSFER_FIRM → const Msg
MESSAGE_END_UPDATE_BLUETOOTH_SETTING → const Msg
MESSAGE_ERROR → const Msg
MESSAGE_PAPER_EMPTY → const Msg
MESSAGE_PREPARATION → const Msg
MESSAGE_PRINT_COMPLETE → const Msg
MESSAGE_PRINT_ERROR → const Msg
MESSAGE_START_COMMUNICATION → const Msg
MESSAGE_START_CONNECT → const Msg
MESSAGE_START_COOLING → const Msg
MESSAGE_START_CREATE_DATA → const Msg
MESSAGE_START_GET_BLUETOOTH_SETTING → const Msg
MESSAGE_START_GET_INPUT_STREAM → const Msg
MESSAGE_START_GET_OUTPUT_STREAM → const Msg
MESSAGE_START_GET_TEMPLATE_LIST → const Msg
MESSAGE_START_READ_PRINTER_STATUS → const Msg
MESSAGE_START_REMOVE_TEMPLATE_LIST → const Msg
MESSAGE_START_SEND_DATA → const Msg
MESSAGE_START_SEND_STATUS_REQUEST → const Msg
MESSAGE_START_SEND_TEMPLATE → const Msg
MESSAGE_START_SOCKET_CLOSE → const Msg
MESSAGE_START_TRANSFER_FIRM → const Msg
MESSAGE_START_UPDATE_BLUETOOTH_SETTING → const Msg
MESSAGE_WAIT_PEEL → const Msg