NetPrinter class

Implemented types

Constructors

NetPrinter({String modelName = "", String serNo = "", String ipAddress = "", String macAddress = "", String nodeName = "", String location = ""})

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String
getter/setter pair
location ↔ String
getter/setter pair
macAddress ↔ String
getter/setter pair
modelName ↔ String
getter/setter pair
nodeName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serNo ↔ String
getter/setter pair

Methods

getName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → NetPrinter