PaperSize class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName() → String
override
getPaperId() → int
getValues() → List<PaperSize>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → PaperSize
getItemId(dynamic index) → int
valueFromID(int id) → PaperSize

Constants

A4 → const PaperSize
A5 → const PaperSize
A5_LANDSCAPE → const PaperSize
A6 → const PaperSize
A7 → const PaperSize
CUSTOM → const PaperSize
LETTER → const PaperSize