PrinterSpec class

Constructors

PrinterSpec({int modelId = 0, int seriesId = 0, int usdId = 0, int headpin = 0, int xDpi = 0, int yDpi = 0, bool printerCase = false, int tubeHeadpin = 0, String modelName = ""})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headpin → int
final
modelId → int
final
modelName → String
final
printerCase → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesId → int
final
tubeHeadpin → int
final
usdId → int
final
xDpi → int
final
yDpi → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → PrinterSpec