TemplateInfo class

Constructors

TemplateInfo({int key = 0, int fileSize = 0, int checksum = 0, Uint8List? modifiedDate, String fileName = "", int modifiedDateRaw = 0})

Properties

checksum → int
final
fileName → String
final
fileSize → int
final
hashCode → int
The hash code for this object.
no setterinherited
key → int
final
modifiedDate → DateTime
final
modifiedDateRaw → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → TemplateInfo