TimeoutSetting class

Constructors

TimeoutSetting({int processTimeoutSec = -1, int sendTimeoutSec = 90, int receiveTimeoutSec = 180, int closeWaitMSec = 500, int connectionWaitMSec = 500, int closeWaitDisusingStatusCheckSec = 3})

Properties

closeWaitDisusingStatusCheckSec ↔ int
getter/setter pair
closeWaitMSec ↔ int
getter/setter pair
connectionWaitMSec ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
processTimeoutSec ↔ int
getter/setter pair
receiveTimeoutSec ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTimeoutSec ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → TimeoutSetting