BrotherUtils class

Constructors

BrotherUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

assetFileToPath(String assetKey) → Future<String>
bytesToImage(Uint8List imageBytes) → Future<Image>
Utility function for turning a byte array into a UI Image. @param imageBytes Byte array of the image.
bytesToTempFile(Uint8List bytesToWrite, String fileName) → Future<String>
Helper funtion to write a set of bytes to a temp file.
loadImage(String assetPath) → Future<Image>
Utility method for getting an UI Image from a resource in the assts. @param assetPath path to retrieve the asset.
printBytes(Uint8List outImageBytes, int pictureWidthBytes) → dynamic
printBytesHex(Uint8List bytes, int hexColCount) → dynamic