TbLabelName class

Implemented types

Constructors

TbLabelName({required String name, int width = _kDefWidth, int height = _kDefHeight, int speed = _kDefSpeed, int density = _kDefDensity, TbSensor sensor = _kDefSensor, int sensorDistance = _kDefDistance, int sensorOffset = _kDefOffset})
Set up the label width, label height, print speed, print density, media sensor type, gap/black mark vertical distance, gap/black mark shift distance. @param width Width of the label in mm @param height Height of the label in mm @param speed Print Speed in inches/second 1.0 : 1.0 inch/second 1.5: 1.5 inches/second 2.0: 2.0 inches/second 3.0: 3.0 inches/second 4.0: 4.0 inches/second 6.0: 6.0 inches/second 8.0: 8.0 inches/second 10.0: 10.0 inches/second 13.0: 13.0 inches/second 14.0: 14.0 inches/second @param density Print Density in the range from 0 to 15 @sensor Media Sensor Type @sensorDistance Sensor Distance - Vertical gap height of the gap/black mark in mm @sensorOffset Sensor Offset - Shift distance of the gap/black mark in mm.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDensity() → int
override
getHeight() → int
override
getName() → String
override
getSensor() → TbSensor
override
getSensorDistance() → int
override
getSensorOffset() → int
override
getSpeed() → int
override
getWidth() → int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) → TbLabelName
getValues() → dynamic

Constants

Unsupported → const TbLabelName