TbModel class

Implemented types

Constructors

TbModel({required String displayName, String discoveryName = "PS-"})
factory
TbModel.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDisplayName() → String
override
getName() → String
Used for searching during things like bt.
override
getValues() → List<TbModel>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueFromName(String name) → TbModel

Constants

RJ_2035B → const TbModel
RJ_2055WB → const TbModel
RJ_3035B → const TbModel
RJ_3055WB → const TbModel
TD_4650TNWB → const TbModel
TD_4650TNWBR → const TbModel
TD_4750TNWB → const TbModel
TD_4750TNWBR → const TbModel
TJ_4420TN → const TbModel
TJ_4422TN → const TbModel
TJ_4520TN → const TbModel
TJ_4522TN → const TbModel
TJ_4620TN → const TbModel
UNKNOWN → const TbModel