TbPrinterStatus class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStatusValue() → int
isHeadOpened() → bool
isOk() → bool
isOtherError() → bool
isOutOfPaper() → bool
isOutOfRibbon() → bool
isPaperJam() → bool
isPaused() → bool
isPrinting() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map map) → TbPrinterStatus

Constants

FLAG_HEAD_OPENED → const int
FLAG_NORMAL → const int
FLAG_OTHER_ERROR → const int
FLAG_OUT_OF_PAPER → const int
FLAG_OUT_OF_RIBBON → const int
FLAG_PAPER_JAM → const int
FLAG_PAUSED → const int
FLAG_PRINTING → const int